@@ -1,7 +1,7 @@
 use std::convert::TryFrom;
 use std::sync::Arc;
 
-use tracing::debug;
+use tracing::{debug, instrument};
 use tokio::sync::OnceCell;
 //use once_cell::sync::OnceCell;
 
@@ -63,8 +63,15 @@ impl Fluvio {
     /// # Ok(())
     /// # }
     /// ```
+    #[instrument(skip(config))]
     pub async fn connect_with_config(config: &FluvioConfig) -> Result<Self, FluvioError> {
         let connector = DomainConnector::try_from(config.tls.clone())?;
+        Self::connect_with_connector(connector, config).await
+    }
+    pub async fn connect_with_connector(
+        connector: DomainConnector,
+        config: &FluvioConfig,
+    ) -> Result<Self, FluvioError> {
         let config = ClientConfig::new(&config.endpoint, connector);
         let inner_client = config.connect().await?;
         debug!("connected to cluster at: {}", inner_client.config().addr());
@@ -115,7 +122,13 @@ impl Fluvio {
     ) -> Result<TopicProducer, FluvioError> {
         let topic = topic.into();
         debug!(topic = &*topic, "Creating producer");
-        Ok(TopicProducer::new(topic, self.spu_pool().await?))
+
+        let spu_pool = self.spu_pool().await?;
+        if !spu_pool.topic_exists(&topic).await? {
+            return Err(FluvioError::TopicNotFound(topic));
+        }
+
+        Ok(TopicProducer::new(topic, spu_pool))
     }
 
     /// Creates a new `PartitionConsumer` for the given topic and partition
@@ -204,3 +217,108 @@ fn check_platform_compatible(cluster_version: &Version) -> Result<(), FluvioErro
 
     Ok(())
 }
+
+#[cfg(test)]
+#[cfg(target_arch = "wasm32")]
+mod wasm_tests {
+    use async_trait::async_trait;
+    use fluvio_ws_stream_wasm::WsMeta;
+    use std::io::Error as IoError;
+    use fluvio_future::{
+        net::{
+            BoxReadConnection, BoxWriteConnection, DomainConnector, TcpDomainConnector,
+            ConnectionFd,
+        },
+    };
+    #[derive(Clone, Default)]
+    pub struct FluvioWebsocketConnector {}
+    impl FluvioWebsocketConnector {
+        pub fn new() -> Self {
+            Self {}
+        }
+    }
+    #[async_trait(?Send)]
+    impl TcpDomainConnector for FluvioWebsocketConnector {
+        async fn connect(
+            &self,
+            addr: &str,
+        ) -> Result<(BoxWriteConnection, BoxReadConnection, ConnectionFd), IoError> {
+            let addr = if addr == "localhost:9010" {
+                "ws://localhost:3001"
+            } else {
+                addr
+            };
+
+            let (mut _ws, wsstream) = WsMeta::connect(addr, None)
+                .await
+                .map_err(|e| IoError::new(std::io::ErrorKind::Other, e))?;
+            let wsstream_clone = wsstream.clone();
+            Ok((
+                Box::new(wsstream.into_io()),
+                Box::new(wsstream_clone.into_io()),
+                String::from(addr),
+            ))
+        }
+
+        fn new_domain(&self, _domain: String) -> DomainConnector {
+            Box::new(self.clone())
+        }
+
+        fn domain(&self) -> &str {
+            "localhost"
+        }
+    }
+    wasm_bindgen_test::wasm_bindgen_test_configure!(run_in_browser);
+    use wasm_bindgen_test::*;
+    use super::*;
+    use crate::metadata::topic::TopicSpec;
+    use futures_util::stream::StreamExt;
+
+    #[wasm_bindgen_test]
+    async fn my_test() {
+        let config = FluvioConfig::new("ws://localhost:3000");
+        let client =
+            Fluvio::connect_with_connector(Box::new(FluvioWebsocketConnector::new()), &config)
+                .await;
+        assert!(client.is_ok());
+        let client = client.unwrap();
+        let mut admin = client.admin().await;
+        let topic = "wasm-test-produce-consume".to_string();
+        /*
+        let err = admin.create(topic, false, TopicSpec::default()).await;
+        tracing::error!("ERROR: {:?}", err);
+        assert!(err.is_ok())
+        */
+        let producer = client.topic_producer(topic.clone()).await;
+        assert!(producer.is_ok());
+        let producer = producer.unwrap();
+        let send = producer.send("foo", "bar").await;
+
+        let consumer = client.partition_consumer(topic, 0).await;
+        assert!(consumer.is_ok());
+        let consumer = consumer.unwrap();
+
+        let stream = consumer.stream(crate::Offset::beginning()).await;
+        assert!(stream.is_ok());
+        let mut stream = stream.unwrap();
+
+        stream.next().await;
+
+        for i in 1..10 {
+            let key = format!("key-{}", i);
+            let value = format!("value-{}", i);
+            let send = producer.send(key.clone(), value.clone()).await;
+            assert!(send.is_ok());
+            let next = stream.next().await;
+            assert!(next.is_some());
+            let next = next.unwrap();
+            assert!(next.is_ok());
+            let next = next.unwrap();
+            assert_eq!(
+                String::from_utf8_lossy(next.key().unwrap()).to_string(),
+                key
+            );
+            assert_eq!(String::from_utf8_lossy(next.value()).to_string(), value);
+        }
+    }
+}
